@@ -23,6 +23,13 @@ def get_discord_color(color: Union[discord.Color, tuple, str]) -> discord.Color:
     A discord.Color object
     """
 
+    print(f"Color: \"{color}\" (type: {type(color)})")
+    print(f"Color is discord.Color: {color is discord.Color}")
+    print(f"Color is discord.Colour: {color is discord.Colour}")
+    print(f"Color isinstance of discord.Color: {isinstance(color, discord.Color)}")
+    print(f"Color isinstance of discord.Colour: {isinstance(color, discord.Colour)}")
+    print(f"Color isinstance of discord.Color or discord.Colour: {isinstance(color, (discord.Color, discord.Colour))}")
+
     if type(color) is tuple:
         # assuming it's RGB
         return discord.Color.from_rgb(color[0], color[1], color[2])
@@ -118,7 +125,7 @@ def slice_string(string: str, max_length: int) -> List[str]:
 def get_base_embed(
     title: Optional[str] = discord.Embed.Empty,
     description: Optional[str] = discord.Embed.Empty,
-    color: Optional[Union[discord.Color, tuple, str]] = discord.Embed.Empty,
+    color: Optional[Union[discord.Color, tuple, str]] = discord.Color.dark_theme(),
     timestamp: Optional[datetime.datetime] = datetime.datetime.utcnow(),
     author: Optional[Union[discord.abc.User, discord.Guild]] = None,
     author_name: Optional[str] = None,
@@ -142,7 +149,8 @@ def get_base_embed(
     description : Optional str
         The embed description
     color : Optional Union(discord.Color, tuple, str)
-        The color to use for the embed. Can be a `discord.Color` object, RGB tuple, or hex string
+        The color to use for the embed. Can be a `discord.Color` object, RGB tuple, or hex string.
+        Defaults to `discord.Color.dark_theme()`
     timestamp : Optional datetime.datetime
         The utc timestamp to use for the embed (defaults to the current utc timestamp)
     author : Optional Union(discord.abc.User, discord.Guild)
